@@ -1,12 +1,11 @@
-from __future__ import unicode_literals
 
-from norm import SELECT
-from norm import INSERT
-from norm import UPDATE
-from norm import DELETE
-from connection import ConnectionFactory
-from connection import ConnectionProxy
-from connection import CursorProxy
+from norm.norm import SELECT
+from norm.norm import INSERT
+from norm.norm import UPDATE
+from norm.norm import DELETE
+from norm.connection import ConnectionFactory
+from norm.connection import ConnectionProxy
+from norm.connection import CursorProxy
 
 
 class SQLI_INSERT(INSERT):
@@ -39,3 +38,12 @@ class SQLI_ConnectionProxy(ConnectionProxy):
 
 class SQLI_ConnectionFactory(ConnectionFactory):
     connection_proxy = SQLI_ConnectionProxy
+
+
+__all__ = [SQLI_INSERT,
+           SQLI_SELECT,
+           SQLI_UPDATE,
+           SQLI_DELETE,
+           SQLI_CursorProxy,
+           SQLI_ConnectionProxy,
+           SQLI_ConnectionFactory]
